@@ -46,3 +46,19 @@ class INavChildren(Interface):
             ...,
         ]
         """
+
+class IAllowedTypes(Interface):
+    def __call__():
+        """Returns allowed types for categorizing."""
+
+class IStartupDir(Interface):
+    def chain():
+        """Returns object chain."""
+    def content_categorized():
+        """Returns start up directory path of content_categorized."""
+    def subcategory():
+        """Returns start up directory path of subcategory."""
+
+class ICategoryContainerObj(Interface):
+    def __call__():
+        """Returns CategoryContainer which belongs to the context hierarchy."""
